Welcome to mirror list, hosted at ThFree Co, Russian Federation.

cygwin.com/git/newlib-cygwin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCorinna Vinschen <corinna@vinschen.de>2010-08-11 14:58:06 +0400
committerCorinna Vinschen <corinna@vinschen.de>2010-08-11 14:58:06 +0400
commita5fe426282c0586415642baf7fb0c880f5f163de (patch)
tree61a8addc9a84decd1407b9a8d55c425f88d871de /winsup/cygwin/include/sys
parentac8050277cdf79784925c06b14b69cf9c02de14a (diff)
* mount.cc (struct opt): Add "bind" option.
(mount_info::from_fstab_line): Handle "bind" option. (fillout_mntent): Add "bind" option to mnt_opts. (mount): Handle "bind" option. * include/sys/mount.h (MOUNT_BIND): New mount flag.
Diffstat (limited to 'winsup/cygwin/include/sys')
-rw-r--r--winsup/cygwin/include/sys/mount.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/winsup/cygwin/include/sys/mount.h b/winsup/cygwin/include/sys/mount.h
index 0fe5e3c74..0680e4562 100644
--- a/winsup/cygwin/include/sys/mount.h
+++ b/winsup/cygwin/include/sys/mount.h
@@ -39,7 +39,8 @@ enum
MOUNT_AUTOMATIC = 0x20000, /* Mount point was added automatically */
MOUNT_DOS = 0x40000, /* convert leading spaces and trailing
dots and spaces to private use area */
- MOUNT_IHASH = 0x80000 /* Enforce hash values for inode numbers */
+ MOUNT_IHASH = 0x80000, /* Enforce hash values for inode numbers */
+ MOUNT_BIND = 0x100000 /* Allows bind syntax in fstab file. */
};
int mount (const char *, const char *, unsigned __flags);